@@ -1,4 +1,4 @@
-### $Id: gnls.R,v 1.7.2.1 2002/07/23 22:23:28 bates Exp $
+### $Id: gnls.R,v 1.7.2.2 2002/08/09 19:45:28 bates Exp $
 ###
 ###  Fit a general nonlinear regression model with correlated and/or
 ###  heteroscedastic errors
@@ -233,7 +233,7 @@ gnls <-
   names(plist) <- pnames
   for (nm in pnames) {
     plist[[nm]] <- TRUE
-    if (deparse(as.vector(params[[nm]][[3]])) != "1") {
+    if (deparse(params[[nm]][[3]]) != "1") {
       plist[[nm]] <-
         model.matrix(asOneSidedFormula(params[[nm]][[3]]),
                  model.frame(asOneSidedFormula(params[[nm]][[3]]), dataModShrunk))
