@@ -1,4 +1,4 @@
-## $Id: lmList.R,v 1.7 2001/10/30 20:51:14 bates Exp $
+## $Id: lmList.R,v 1.8 2002/03/05 15:36:27 bates Exp $
 ###
 ###                  Create a list of lm objects
 ###
@@ -210,7 +210,7 @@ coef.lmList <-
       attr(coefs, "level") <- attr(object, "level")
       attr(coefs, "label") <- "Coefficients"
       attr(coefs, "effectNames") <- effectNames
-      attr(coefs, "standardized") <- F
+      attr(coefs, "standardized") <- FALSE
       attr(coefs, "grpNames") <- deparse(getGroupsFormula(object)[[2]])
       class(coefs) <- c("coef.lmList", "ranef.lmList", class(coefs))
     }
@@ -539,12 +539,14 @@ pairs.lmList <-
     args <- c(args,
 	      panel = list(function(x, y, subscripts, ...)
 		  {
+                    x <- as.numeric(x)
+                    y <- as.numeric(y)
                     dots <- list(...)
 		    if (grid) panel.grid()
 		    panel.xyplot(x, y)
                     if (any(ids <- id[subscripts])) {
-                        text(x[ids], y[ids], idLabels[subscripts][ids],
-                             cex = dots$cex, adj = dots$adj)
+                        ltext(x[ids], y[ids], idLabels[subscripts][ids],
+                              cex = dots$cex, adj = dots$adj)
 		    }
 		  }))
   } else {				# splom
@@ -552,12 +554,14 @@ pairs.lmList <-
     args <- c(args,
 	      panel = list(function(x, y, subscripts, ...)
 		  {
+                    x <- as.numeric(x)
+                    y <- as.numeric(y)
                     dots <- list(...)
 		    if (grid) panel.grid()
 		    panel.xyplot(x, y)
                     if (any(ids <- id[subscripts])) {
-                        text(x[ids], y[ids], idLabels[subscripts][ids],
-                             cex = dots$cex, adj = dots$adj)
+                        ltext(x[ids], y[ids], idLabels[subscripts][ids],
+                              cex = dots$cex, adj = dots$adj)
 		    }
 		  }))
   }
@@ -598,6 +602,8 @@ plot.intervals.lmList <-
 	      col = dot.symbol$col, cex = dot.symbol$cex,
 	      font = dot.symbol$font, ...)
 	  {
+            x <- as.numeric(x)
+            y <- as.numeric(y)
 	    ok <- !is.na(x) & !is.na(y)
 	    yy <- y[ok]
 	    xx <- x[ok]
@@ -771,12 +777,14 @@ plot.lmList <-
       args <- c(args,
 		panel = list(function(x, y, subscripts, ...)
 		    {
+                      x <- as.numeric(x)
+                      y <- as.numeric(y)
                       dots <- list(...)
 		      if (grid) panel.grid()
 		      panel.xyplot(x, y)
                       if (any(ids <- id[subscripts])) {
-                          text(x[ids], y[ids], idLabels[subscripts][ids],
-                               cex = dots$cex, adj = dots$adj)
+                          ltext(x[ids], y[ids], idLabels[subscripts][ids],
+                                cex = dots$cex, adj = dots$adj)
                       }
 		      if (!is.null(abl)) {
 			panel.abline(abl, ...)
@@ -799,6 +807,8 @@ plot.lmList <-
     args <- c(args,
 	      panel = list(function(x, y, ...)
 		  {
+                    x <- as.numeric(x)
+                    y <- as.numeric(y)
 		    if (grid) panel.grid()
 		    panel.histogram(x, y)
 		    if (!is.null(abl)) {
@@ -808,7 +818,7 @@ plot.lmList <-
   }
   ## defining grid
   if (missing(grid)) {
-    if (plotFun == "xyplot") grid <- T
+    if (plotFun == "xyplot") grid <- TRUE
     else grid <- FALSE
   }
   assign("grid", grid)
@@ -1184,12 +1194,14 @@ qqnorm.lmList <-
   args <- c(list(formula = eval(parse(text = dform)),
                  data = substitute(data),
                  panel = function(x, y, subscripts, ...){
+                   x <- as.numeric(x)
+                   y <- as.numeric(y)
                    dots <- list(...)
                    if (grid) panel.grid()
                    panel.xyplot(x, y, ...)
                    if (any(ids <- id[subscripts])) {
-                       text(x[ids], y[ids], idLabels[subscripts][ids],
-                            cex = dots$cex, adj = dots$adj)
+                       ltext(x[ids], y[ids], idLabels[subscripts][ids],
+                             cex = dots$cex, adj = dots$adj)
                    }
                    if (!is.null(abl)) panel.abline(abl, ...)
                  }), args)
